@@ -19,8 +19,6 @@
 
 #pragma once
 
-#include <glib.h>
-
 /**
  * SECTION: version
  * @section_id: version-macros
@@ -38,7 +36,7 @@
  *
  * Since: 0.10.0
  */
-#define GARROW_VERSION_MAJOR (15)
+#define GARROW_VERSION_MAJOR (16)
 
 /**
  * GARROW_VERSION_MINOR:
@@ -47,7 +45,7 @@
  *
  * Since: 0.10.0
  */
-#define GARROW_VERSION_MINOR (0)
+#define GARROW_VERSION_MINOR (1)
 
 /**
  * GARROW_VERSION_MICRO:
@@ -56,7 +54,7 @@
  *
  * Since: 0.10.0
  */
-#define GARROW_VERSION_MICRO (2)
+#define GARROW_VERSION_MICRO (0)
 
 /**
  * GARROW_VERSION_TAG:
@@ -110,6 +108,15 @@
 #  define GARROW_UNAVAILABLE(major, minor) G_UNAVAILABLE(major, minor)
 #endif
 
+/**
+ * GARROW_VERSION_16_0:
+ *
+ * You can use this macro value for compile time API version check.
+ *
+ * Since: 16.0.0
+ */
+#define GARROW_VERSION_16_0 G_ENCODE_VERSION(16, 0)
+
 /**
  * GARROW_VERSION_15_0:
  *
@@ -355,6 +362,20 @@
 
 #define GARROW_AVAILABLE_IN_ALL
 
+#if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_16_0
+#  define GARROW_DEPRECATED_IN_16_0                GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_16_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#else
+#  define GARROW_DEPRECATED_IN_16_0
+#  define GARROW_DEPRECATED_IN_16_0_FOR(function)
+#endif
+
+#if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_16_0
+#  define GARROW_AVAILABLE_IN_16_0 GARROW_UNAVAILABLE(16, 0)
+#else
+#  define GARROW_AVAILABLE_IN_16_0
+#endif
+
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_15_0
 #  define GARROW_DEPRECATED_IN_15_0                GARROW_DEPRECATED
 #  define GARROW_DEPRECATED_IN_15_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
